import { AxiosInstance, AxiosRequestConfig } from 'axios';
import { CookieJar } from 'tough-cookie';
import { BaseResponseData, FollowResponse, HashtagSearchResponse, JoinLiveStreamResponse, LikePostResponse, ListCategoriesRequest, ListCategoriesResponse, ListCommentsRequest, ListCommentsResponse, ListFeedRequest, ListFeedResponse, ListFollowersRequest, ListFollowersResponse, ListFollowingRequest, ListFollowingResponse, ListForYouFeedResponse, ListPostsRequest, ListPostsResponse, LoginRequest, LoginResponse, PostCommentResponse, RequiredUserDefinedRequestParams, SearchRequest, StaticRequestParams, Tag, TikTokAPIConfig, UserProfileResponse, UserSearchRequest, UserSearchResponse } from './types';
export default class TikTokAPI {
    readonly config: TikTokAPIConfig;
    readonly cookieJar: CookieJar;
    readonly request: AxiosInstance;
    constructor(requestParams: StaticRequestParams, apiConfig: TikTokAPIConfig, requestConfig?: AxiosRequestConfig);
    loginWithEmail: (email: string, password: string) => import("../node_modules/axios/index").AxiosPromise<LoginResponse>;
    login: (params: LoginRequest) => import("../node_modules/axios/index").AxiosPromise<LoginResponse>;
    getUser: (userId: string) => import("../node_modules/axios/index").AxiosPromise<UserProfileResponse | BaseResponseData>;
    searchUsers: (params: UserSearchRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | UserSearchResponse>;
    listPosts: (params: ListPostsRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListPostsResponse>;
    listFollowers: (params: ListFollowersRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListFollowersResponse>;
    listFollowing: (params: ListFollowingRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListFollowingResponse>;
    follow: (userId: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | FollowResponse>;
    unfollow: (userId: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | FollowResponse>;
    likePost: (postId: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | LikePostResponse>;
    unlikePost: (postId: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | LikePostResponse>;
    listComments: (params: ListCommentsRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListCommentsResponse>;
    postComment: (postId: string, text: string, tags?: Tag[]) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | PostCommentResponse>;
    listCategories: (params?: ListCategoriesRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListCategoriesResponse>;
    searchHashtags: (params: SearchRequest) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | HashtagSearchResponse>;
    listForYouFeed: (params?: ListFeedRequest | undefined) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListForYouFeedResponse>;
    listFollowingFeed: (params?: ListFeedRequest | undefined) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | ListFeedResponse>;
    joinLiveStream: (id: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData | JoinLiveStreamResponse>;
    leaveLiveStream: (id: string) => import("../node_modules/axios/index").AxiosPromise<BaseResponseData>;
    transformResponse: (data: any) => any;
    private signRequest;
}
export declare const getRequestParams: (requestParams: RequiredUserDefinedRequestParams) => StaticRequestParams;
export * from './types';
